==> qttranslations-opensource-src_5.4.2.orig.tar.xz: qttranslations-opensource-src-5.4.2/translations/qtquickcontrols_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>DefaultColorDialog</name>
    <message>
        <source>Hue</source>
        <translation>Farbton</translation>
    </message>
    <message>
        <source>Saturation</source>
        <translation>Sättigung</translation>
    </message>
    <message>
        <source>Luminosity</source>
        <translation>Helligkeit</translation>
    </message>
    <message>
        <source>Alpha</source>
        <translation>Alpha</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>DefaultDialogWrapper</name>
    <message>
        <source>Show Details...</source>
        <translation>Details anzeigen...</translation>
    </message>
</context>
<context>
    <name>DefaultFileDialog</name>
    <message>
        <source>Go up to the folder containing this one</source>
        <translation>Gehe nach oben zum Ordner, der diesen enthält</translation>
    </message>
    <message>
        <source>Remove favorite</source>
        <translation>Favoriten löschen</translation>
    </message>
    <message>
        <source>Add the current directory as a favorite</source>
        <translation>Aktuellen Ordner als Favoriten hinzufügen</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Dateiname</translation>
    </message>
    <message>
        <source>Type</source>
        <comment>file type (extension)</comment>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>file size</comment>
        <translation>Größe</translation>
    </message>
    <message>
        <source>Modified</source>
        <comment>last-modified time</comment>
        <translation>Letzte Änderung</translation>
    </message>
    <message>
        <source>Accessed</source>
        <comment>last-accessed time</comment>
        <translation>Letzter Zugriff</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>DefaultFontDialog</name>
    <message>
        <source>Writing System</source>
        <translation>Schriftsystem</translation>
    </message>
    <message>
        <source>Font</source>
        <translation>Schriftart</translation>
    </message>
    <message>
        <source>Weight</source>
        <translation>Dicke</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <source>Font Family</source>
        <translation>Schriftfamilie</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Unterstrichen</translation>
    </message>
    <message>
        <source>Overline</source>
        <translation>Überstrichen</translation>
    </message>
    <message>
        <source>Strikeout</source>
        <translation>Durchgestrichen</translation>
    </message>
    <message>
        <source>Sample</source>
        <translation>Beispiel</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Schriftstil</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>DefaultMessageDialog</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation>Alles Speichern</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Wiederholen</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorieren</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>Yes to All</source>
        <translation>Ja, alle</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <source>No to All</source>
        <translation>Nein, keine</translation>
    </message>
    <message>
        <source>Discard</source>
        <translation>Verwerfen</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Voreinstellungen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>Show Details...</source>
        <translation>Details anzeigen...</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>Hide Details</source>
        <translation>Details verbergen</translation>
    </message>
</context>
</TS>

==> qttranslations-opensource-src_5.5.1.orig.tar.xz: qttranslations-opensource-src-5.5.1/translations/qtquickcontrols_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>DefaultColorDialog</name>
    <message>
        <source>Hue</source>
        <translation>Farbton</translation>
    </message>
    <message>
        <source>Saturation</source>
        <translation>Sättigung</translation>
    </message>
    <message>
        <source>Luminosity</source>
        <translation>Helligkeit</translation>
    </message>
    <message>
        <source>Alpha</source>
        <translation>Alpha</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>DefaultDialogWrapper</name>
    <message>
        <source>Show Details...</source>
        <translation>Details anzeigen...</translation>
    </message>
</context>
<context>
    <name>DefaultFileDialog</name>
    <message>
        <source>Go up to the folder containing this one</source>
        <translation>Gehe nach oben zum Ordner, der diesen enthält</translation>
    </message>
    <message>
        <source>Remove favorite</source>
        <translation>Favoriten löschen</translation>
    </message>
    <message>
        <source>Add the current directory as a favorite</source>
        <translation>Aktuellen Ordner als Favoriten hinzufügen</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Dateiname</translation>
    </message>
    <message>
        <source>Type</source>
        <comment>file type (extension)</comment>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>file size</comment>
        <translation>Größe</translation>
    </message>
    <message>
        <source>Modified</source>
        <comment>last-modified time</comment>
        <translation>Letzte Änderung</translation>
    </message>
    <message>
        <source>Accessed</source>
        <comment>last-accessed time</comment>
        <translation>Letzter Zugriff</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation>Auswählen</translation>
    </message>
</context>
<context>
    <name>DefaultFontDialog</name>
    <message>
        <source>Writing System</source>
        <translation>Schriftsystem</translation>
    </message>
    <message>
        <source>Font</source>
        <translation>Schriftart</translation>
    </message>
    <message>
        <source>Weight</source>
        <translation>Dicke</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <source>Font Family</source>
        <translation>Schriftfamilie</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Unterstrichen</translation>
    </message>
    <message>
        <source>Overline</source>
        <translation>Überstrichen</translation>
    </message>
    <message>
        <source>Strikeout</source>
        <translation>Durchgestrichen</translation>
    </message>
    <message>
        <source>Sample</source>
        <translation>Beispiel</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Schriftstil</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>DefaultMessageDialog</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation>Alles Speichern</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Wiederholen</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorieren</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>Yes to All</source>
        <translation>Ja, alle</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <source>No to All</source>
        <translation>Nein, keine</translation>
    </message>
    <message>
        <source>Discard</source>
        <translation>Verwerfen</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Voreinstellungen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>Show Details...</source>
        <translation>Details anzeigen...</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>Hide Details</source>
        <translation>Details verbergen</translation>
    </message>
</context>
<context>
    <name>EditMenu_base</name>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Rückgängig</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>Wieder&amp;herstellen</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>&amp;Ausschneiden</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopieren</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>Einf&amp;ügen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Alles löschen</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Alles auswählen</translation>
    </message>
</context>
<context>
    <name>EditMenu_ios</name>
    <message>
        <source>Cut</source>
        <translation>Ausschneiden</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Einsetzen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Auswählen</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Alles</translation>
    </message>
</context>
</TS>
